#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2022 Univention GmbH
#
# https://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <https://www.gnu.org/licenses/>.


import json
import os

inventory = {
    "hosts": {
        "hosts": [
            os.environ["UCS_ENV_TRAEGER1_FQDN"],
            os.environ["UCS_ENV_TRAEGER2_FQDN"],
        ],
        "vars": {
            "omar": "192.168.0.10",
            "ansible_python_interpreter": "/usr/bin/python3",
            "ansible_ssh_private_key_file": os.environ["UCS_ENV_ANSIBLE_SSH_PRIVATE_KEY"],
            "ansible_ssh_user": os.environ["UCS_ENV_ANSIBLE_SSH_USER"],
            "ansible_ssh_common_args": "-o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null",
        },
    },
    "_meta": {
        "hostvars": {
            os.environ["UCS_ENV_TRAEGER1_FQDN"]: {
                "ansible_host": os.environ["UCS_ENV_TRAEGER1_FQDN"],
                "ldif_url": "http://{{ omar }}/build2/ucs_5.0-0-id-broker-5.0/data/traeger1_ldif.tar.xz",
            },
            os.environ["UCS_ENV_TRAEGER2_FQDN"]: {
                "ansible_host": os.environ["UCS_ENV_TRAEGER2_FQDN"],
                "ldif_url": "http://{{ omar }}/build2/ucs_5.0-0-id-broker-5.0/data/traeger2_ldif.tar.xz",
            },
        }
    },
}

for broker_system in os.environ["UCS_ENV_BROKER_LDAPS"].split(" "):
    inventory["hosts"]["hosts"].append(broker_system)
    inventory["_meta"]["hostvars"][broker_system] = {
        "ansible_host": broker_system,
        "ldif_url": "http://{{ omar }}/build2/ucs_5.0-0-id-broker-5.0/data/id_broker_ldif.tar.xz",
    }

print(json.dumps(inventory))
