#!/usr/share/ucs-test/runner pytest-3 -s -l -v
## -*- coding: utf-8 -*-
## desc: Check test app login, get access token and verify self disclosure user metadata
## tags: [ucsschool-id-broker]
## packages: [id-broker-provisioning-api-plugin]
## exposure: safe


import os

import pytest
from utils import get_self_disclosure_metadata, ucs_saml_login, univention_test_app_login_with_saml


@pytest.mark.parametrize(
    "uid",
    [
        "Traeger1-stud1",
        "Traeger1-teach1",
        "Traeger2-stud1",
        "Traeger2-teach1",
    ],
)
def test_login_with_saml_assertion(udm, uid):
    traeger = uid.split("-")[0]
    username = uid.split("-", 1)[1]
    kdc_idp_hint = traeger.lower()
    traeger_fqdn = os.environ.get(f"UCS_ENV_{traeger.upper()}_FQDN")
    test_app_fqdn = os.environ.get("UCS_ENV_TEST_APP_FQDN")
    assert traeger_fqdn
    assert test_app_fqdn
    password = "univention"  # TODO
    saml_cookies = ucs_saml_login(username, password, traeger_fqdn)
    access_token = univention_test_app_login_with_saml(kdc_idp_hint, test_app_fqdn, saml_cookies)
    user_metadata = get_self_disclosure_metadata(access_token)
    udm_mod = udm.get("users/user")
    broker_user = list(udm_mod.search(f"uid={uid}"))[0]
    # check self disclosure metadata and broker user
    assert user_metadata["username"] == broker_user.props.username.replace(f"{traeger}-", "")
    assert user_metadata["firstname"] == broker_user.props.firstname
    assert user_metadata["lastname"] == broker_user.props.lastname
    assert user_metadata["school_id"] in [
        school.replace(f"{traeger}-", "") for school in broker_user.props.school
    ]
    assert user_metadata["type"] in [role.split(":")[0] for role in broker_user.props.ucsschoolRole]
